#!/bin/bash

# Check for expat library
EXPATLIB=libexpat.a
if [ -f /lib/$EXPATLIB ]; then
  found=1
elif [ -f /usr/lib/$EXPATLIB ]; then
  found=1
elif [ -f /usr/local/lib/$EXPATLIB ]; then
  found=1
else
	echo "Expat library not found, please install: http://sourceforge.net/projects/expat"
	exit
fi

# USE THE CORRECT PERL BINARY AND TMP DIRS
whichos=`uname`
PATCHER=patch
if [ "$whichos" = "SunOS" ]; then
	PATH=/usr/local/bin:/usr/ccs/bin:$PATH
	PATCHER=gpatch
fi
PATH=$PWD/PerlSrc/perl/bin:$PATH
export PATH
TEMPDIR=$PWD/tmp
TMP=$PWD/tmp
export TMP
export TEMPDIR
if [ -d tmp ]; then
	/bin/rm -rf tmp
fi
mkdir tmp


# UNPACK AND BUILD REQUIRED MODULES
if [ -d PerlModules ]; then
	/bin/rm -rf PerlModules
fi
mkdir PerlModules
cd PerlModules

perl -e 'use ExtUtils::Installed; my ($inst) = ExtUtils::Installed->new(); my (@modules) = $inst->modules(); foreach (@modules) { my $vrs = $inst->version($_); print "$_\t$vrs\n"; }' > cur-modules.list

# ... FOR PAR
for ff in `cat ../par-deps.list`; do         
	f=`echo $ff | sed -e 's/::/-/g'`
	if [ "$ff" = "HTML::Tree" ] ; then 
		ff="HTML-Tree"
	fi
	have=`egrep "^$ff" cur-modules.list | wc -l | awk '{ print $1; }'`
	if [ $have -gt 0 ] ; then 
		echo $ff already installed
		continue
	fi
	echo INSTALLING $f
	gzip -dc ../Tars/$f-[0-9]*.tar.gz | tar xvf -
	#tar zxvf ../Tars/$f-[0-9]*.tar.gz
	cd $f-[0-9]*
	if [ -f Makefile ] ; then
		make clean
		/bin/rm Makefile.old
	fi
	if [ "$f" = "libwww-perl" ] ; then
		yes "n" | perl Makefile.PL
	elif [ "$f" = "Math-Pari" ] ; then
		gzip -dc ../../Tars/pari-2.1.7.tgz | tar xvf -
		#tar zxvf ../../Tars/pari-2.1.7.tgz
		perl Makefile.PL machine=none
	elif [ "$f" = "HTML-Parser" ] ; then
		yes "no" | perl Makefile.PL
	elif [ "$f" = "Crypt-OpenPGP" ] ; then
		yes "n" | perl Makefile.PL
	elif [ "$f" = "Module-Signature" ] ; then
		yes "n" | perl Makefile.PL
	else
		perl Makefile.PL
	fi
	sleep 4
	make
	make test
	sleep 2
	make install
	cd ..
done

# Build PAR
have=`egrep "^PAR[^:A-Za-z0-9]" cur-modules.list | wc -l | awk '{ print $1; }'`
if [ $have -gt 0 ] ; then 
	echo PAR already installed
else
	echo INSTALLING PAR
	gzip -dc ../Tars/PAR-[0-9]*.tar.gz | tar xvf -
	# tar zxvf ../Tars/PAR-[0-9]*.tar.gz
	cd PAR-[0-9]*
	if [ -f Makefile ] ; then
		make clean
		/bin/rm Makefile.old
	fi
	perl Makefile.PL
	make
	make test
	sleep 2
	make install
	cd ..
fi

# Reset module list
/bin/rm cur-modules.list
perl -e 'use ExtUtils::Installed; my ($inst) = ExtUtils::Installed->new(); my (@modules) = $inst->modules(); foreach (@modules) { my $vrs = $inst->version($_); print "$_\t$vrs\n"; }' > cur-modules.list

# ... FOR VCP
#
# unzip any zips
#
for ff in ../Tars/*.zip; do
	unzip $ff
done
for ff in `cat ../vcp-deps.list`; do
	f=`echo $ff | sed -e 's/::/-/g'`
	if [ "$ff" = "HTML::Tree" ] ; then 
		ff="HTML-Tree"
	fi
	if [ "$ff" = "HTML::Format" ] ; then 
		ff="HTML-Format"
	fi
	have=`egrep "^$ff" cur-modules.list | wc -l | awk '{ print $1; }'`
	if [ $have -gt 0 ] ; then 
		echo $ff already installed
		continue
	fi
	echo INSTALLING $f
	gzip -dc ../Tars/$f-*.tar.gz | tar xvf -
	#tar zxvf ../Tars/$f-*.tar.gz
	cd $f-[0-9]*.*
	if [ -f Makefile ] ; then
		make clean
		/bin/rm Makefile.old
	fi
	perl Makefile.PL
	if [ "$f" = "PodToHTML" ]; then
		# Patch the HTML_Elements.pm file
		$PATCHER -R -i ../../PodToHTML.Pod.HTML_Elements.pm.patch Pod/HTML_Elements.pm
	fi
	make
	make test
	sleep 2
	make install
	cd ..
done
